/**
 * @file
 * JavaScript file for the Coffee module.
 */

(function($) {
  // Remap the filter functions for autocomplete to recognise the
  // extra value "command".
  var proto = $.ui.autocomplete.prototype,
    initSource = proto._initSource;

  function filter(array, term) {
    var matcher = new RegExp($.ui.autocomplete.escapeRegex(term), 'i');
    return $.grep(array, function(value) {
                return matcher.test(value.command) || matcher.test(value.label) || matcher.test(value.value);
    });
  }

  $.extend(proto, {
    _initSource: function() {
      if ($.isArray(this.options.source)) {
        this.source = function(request, response) {
          response(filter(this.options.source, request.term));
        };
      }
      else {
        initSource.call(this);
      }
    }
  });

  Drupal.coffee = Drupal.coffee || {};

  Drupal.behaviors.coffee = {
    attach: function() {
      $('body').once('coffee', function() {
        var body = $(this);

        Drupal.coffee.bg.appendTo(body).hide();

        Drupal.coffee.form
        .append(Drupal.coffee.label)
        .append(Drupal.coffee.field)
        .append(Drupal.coffee.results)
        .wrapInner('<div id="coffee-form-inner" />')
        .addClass('hide-form')
        .appendTo(body);

        // Load autocomplete data set, implementing caching with local storage.
        Drupal.coffee.dataset = [];
        Drupal.coffee.hasLocalStorage = false;
        if (typeof(Storage) !== 'undefined') {
          Drupal.coffee.hasLocalStorage = true;
        }

        // Code for localStorage/sessionStorage.
        if (Drupal.coffee.hasLocalStorage) {
          data = sessionStorage.getItem('coffeeDataSet');
          if (data && data.length) {
            Drupal.coffee.dataset = JSON.parse(data);
          }
        }

        if (Drupal.coffee.dataset && Drupal.coffee.dataset.length) {
          buildAutoComplete();
        }
        else {
          doAjaxRequest();
        }

        Drupal.coffee.isItemSelected = false;

        var jquery_ui_version = $.ui.version.split('.');
        var jquery_ui_newer_1_9 = parseInt(jquery_ui_version[0]) >= 1 && parseInt(jquery_ui_version[1]) > 9;
        var autocomplete_data_element = (jquery_ui_newer_1_9) ? 'ui-autocomplete' : 'autocomplete';

        function buildAutoComplete() {
          // Apply autocomplete plugin on show
          var $autocomplete = $(Drupal.coffee.field).autocomplete({
            source: Drupal.coffee.dataset,
            focus: function(event, ui) {
              Drupal.coffee.isItemSelected = true;
              // Prevents replacing the value of the input field
              event.preventDefault();
            },
            change: function(event, ui) {
              Drupal.coffee.isItemSelected = false;
            },
            select: function(event, ui) {
              Drupal.coffee.redirect(ui.item.value, event.metaKey);
              event.preventDefault();
              return false;
            },
            delay: 0,
            appendTo: Drupal.coffee.results
          });

          $autocomplete.data(autocomplete_data_element)._renderItem = function(ul, item) {
            return  $('<li></li>')
              .data('item.autocomplete', item)
              .append(
                '<a href="' + item.value + '">' + (item.parent ? item.parent + ' &raquo; ' : '') + item.label +
                '<small class="description">' + item.value + '</small>' +
                '</a>')
              .appendTo(ul);
          };

          // This isn't very nice, there are methods within that we need
          // to alter, so here comes a big wodge of text...
          var self = Drupal.coffee.field;
          if (!jquery_ui_newer_1_9) {
            $(Drupal.coffee.field).data(autocomplete_data_element).menu = $('<ol></ol>')
              .addClass('ui-autocomplete')
              .appendTo(Drupal.coffee.results)
              // prevent the close-on-blur in case of a "slow" click on the menu (long mousedown).
              .mousedown(function(event) {
                event.preventDefault();
              })
              .menu({
                selected: function(event, ui) {
                  var item = ui.item.data('item.autocomplete');
                  Drupal.coffee.redirect(item.value, event.metaKey);
                  event.preventDefault();
                },
                focus: function(event, ui) {
                  Drupal.coffee.isItemSelected = true;
                }
              })
              .hide()
              .data('menu');
          }

          // We want to limit the number of results.
          $(Drupal.coffee.field).data(autocomplete_data_element)._renderMenu = function(ul, items) {
            var self = this;
            //@todo: max should be in Drupal.settings var.
            items = items.slice(0, 7);
            $.each(items, function(index, item) {
              if (typeof(self._renderItemData) === "undefined") {
                self._renderItem(ul, item);
              }
              else {
                self._renderItemData(ul, item);
              }
            });
          };

          Drupal.coffee.form.keydown(function(event) {
            if (event.keyCode == 13) {
              var openInNewWindow = false;

              if (event.metaKey) {
                openInNewWindow = true;
              }
              if (!Drupal.coffee.isItemSelected) {
                var $firstItem = jQuery(Drupal.coffee.results).find('li:first').data('item.autocomplete');
                if (typeof $firstItem === 'object') {
                  Drupal.coffee.redirect($firstItem.value, openInNewWindow);
                  event.preventDefault();
                }
              }
            }
          });
        }

        function doAjaxRequest() {
          $.ajax({
            url: Drupal.settings.basePath + '?q=admin/coffee/menu',
            dataType: 'json',
            success: function(data) {
              Drupal.coffee.dataset = data;
              // If we have local storage, store the data on the session.
              if (Drupal.coffee.hasLocalStorage) {
                sessionStorage.setItem('coffeeDataSet', JSON.stringify(data));
              }
              buildAutoComplete();
            },
            error: function() {
              Drupal.coffee.field.val('Could not load data, please refresh the page');
            }
          });
        }

        // Key events
        $(document).keydown(function(event) {
          var activeElement = $(document.activeElement);

          // Show the form with alt + D. Use 2 keycodes as 'D' can be uppercase or lowercase.
          if (Drupal.coffee.form.hasClass('hide-form') &&
              event.altKey === true &&
              // 68/206 = d/D, 75 = k.
              (event.keyCode === 68 || event.keyCode === 206  || event.keyCode === 75)) {
            Drupal.coffee.coffee_show();
            event.preventDefault();
          }
          // Close the form with esc or alt + D.
          else if (!Drupal.coffee.form.hasClass('hide-form') && (event.keyCode === 27 || (event.altKey === true && (event.keyCode === 68 || event.keyCode === 206)))) {
            Drupal.coffee.coffee_close();
            event.preventDefault();
          }
        });
      });
    }
  };

  // Prefix the open and close functions to avoid
  // conflicts with autocomplete plugin.

  /**
   * Open the form and focus on the search field.
   */
  Drupal.coffee.coffee_show = function() {
    Drupal.coffee.form.removeClass('hide-form');
    Drupal.coffee.bg.show();
    Drupal.coffee.field.focus();
    $(Drupal.coffee.field).autocomplete({enable: true});
  };

  /**
   * Close the form and destroy all data.
   */
  Drupal.coffee.coffee_close = function() {
    Drupal.coffee.field.val('');
    //Drupal.coffee.results.empty();
    Drupal.coffee.form.addClass('hide-form');
    Drupal.coffee.bg.hide();
    $(Drupal.coffee.field).autocomplete({enable: false});
  };

  /**
   * Close the Coffee form and redirect.
   * Todo: make it work with the overlay module.
   */
  Drupal.coffee.redirect = function(path, openInNewWindow) {
    Drupal.coffee.coffee_close();

    if (openInNewWindow) {
      window.open(Drupal.settings.basePath + path);
    }
    else {
      document.location = Drupal.settings.basePath + path;
    }
  };

  /**
   * The HTML elements.
   */
  Drupal.coffee.label = $('<label for="coffee-q" class="element-invisible" />').text(Drupal.t('Query'));

  Drupal.coffee.results = $('<div id="coffee-results" />');

  // Instead of appending results one by one, we put them in a placeholder element
  // first and then append them all at once to prevent flickering while typing.
  Drupal.coffee.resultsPlaceholder = $('<ol />');

  Drupal.coffee.form = $('<form id="coffee-form" action="#" />');

  Drupal.coffee.bg = $('<div id="coffee-bg" />').click(function() {
    Drupal.coffee.coffee_close();
  });

  Drupal.coffee.field = $('<input id="coffee-q" type="text" autocomplete="off" />');

}(jQuery));
